# AnalysisResultResponseResultDeb

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**arch** | **str** | Package architecture |
**name** | **str** | Name of the Debian package |
**version** | **str** | Version identifier of the Debian package |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

